@@ -1,7 +1,5 @@
 from ..oddrn.postgres import get_table_oddrn
 
-from .. import settings
-
 class PostgresExtractor:
     def __init__(self, task):
         self._db = task.postgres_conn_id
@@ -11,6 +9,7 @@ class PostgresExtractor:
         for table in tables:
             source = table.split(".")
             if len(source) > 1:
+                # Schema included
                 oddrn = get_table_oddrn(self._db, source[0],  source[1])
             else:
                 oddrn = get_table_oddrn(self._db, "public", source[0])
