@@ -1,10 +1,13 @@
-from .. import settings
-
 from oddrn import Generator
 
+from .. import settings
+
 airflow_generator = Generator(data_source=settings.AIRFLOW_SOURCE, cloud=settings.CLOUD)
 
 
+def get_datasource_oddrn() -> str:
+    return airflow_generator.get_base()
+
 def get_transformer_oddrn(dag_id: str, task_id: str) -> str:
     return airflow_generator.get_task(dag_id, task_id)
 
